# CreateBillingCheckoutSession

create a checkout session options

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**ui_mode** | **str** | The ui_mode. When ommited, defaults to embedded. | [optional] 
**return_url** | **str** | The return url. | [optional] 
**success_url** | **str** | The success_url. | [optional] 
**custom_text** | **str** | custom text | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


